@@ -72,10 +72,9 @@ public:
     /**
       * Creates a new InfoSidebar instance.
       * @param p_game the game instance
-      * @param p_renderer the renderer instance
       * @param p_scene the gamescene instance
       */
-    InfoSidebar (Game* p_game, GameScene* p_scene);
+    explicit InfoSidebar (Game* p_game, GameScene* p_scene);
 
     /**
       * Deletes the InfoSidebar instance.
@@ -97,7 +96,7 @@ public:
       */
     void themeChanged();
 
-private slots:
+private Q_SLOTS:
     /**
       * sets the bonus info
       * @param player the player which info changed
@@ -106,7 +105,7 @@ private slots:
       */
     void bonusInfoChanged(Player* player, Granatier::Bonus::Type bonusType, int percentageElapsed);
 
-public slots:
+public Q_SLOTS:
     /**
      * Updates the graphics after a resize
      * @param svgScaleFactor the scaling factor between svg and rendered pixmap
